-------------------------------------------------------------------------------
-- MrTrader 0.1
--
-- Lightweight addon to access profession information of alts.
--
-- Send suggestions, comments, and bugs to user@zedonline.net
-------------------------------------------------------------------------------

local L = LibStub("AceLocale-3.0"):GetLocale("MrTrader", true);

local Defaults = {
	factionrealm = {
		skills = {},
	}
}

-- List of tradeskills
-- Key: Nonlocalized name
-- Value: true if this skill has a tradeskill link you can share
local TradeSkills = {
	["Alchemy"] = true, 
	["Blacksmithing"] = true,
	["Cooking"] = true,
	["Enchanting"] = true,
	["Engineering"] = true,
	["First Aid"] = true,
	["Inscription"] = true,
	["Jewelcrafting"] = true,
	["Leatherworking"] = true,
	["Runeforging"] = false,
	["Smelting"] = false,
	["Tailoring"] = true,
}

function MrTrader:Load()
	self.db = LibStub("AceDB-3.0"):New("MrTraderDB", Defaults, "Default");
end

function MrTrader:QuerySkills()
	local currentPlayer = UnitName("player");	
	local skillTable = {};
	local oldTable = {};
	local didGrabUpdate = true;
	
	if self.db.factionrealm.skills[currentPlayer] then
		oldTable = self.db.factionrealm.skills[currentPlayer];
	end
	
	for skillName, usesLink in pairs(TradeSkills) do
		doesExist, tradeLink = GetSpellLink(L[skillName]);
		
		if doesExist and tradeLink then
			skillTable[skillName] = tradeLink;
		elseif doesExist and oldTable[skillName] then
			skillTable[skillName] = oldTable[skillName];
			didGrabUpdate = false;
		elseif doesExist then
			skillTable[skillName] = false;
			if usesLink then
				didGrabUpdate = false;
			end
		end
	end
	
	if self:TableSize(skillTable) > 0 then
		self.db.factionrealm.skills[currentPlayer] = skillTable;
		return didGrabUpdate;
	else
		self.db.factionrealm.skills[currentPlayer] = nil;
		return true;
	end
end

function MrTrader:GetSkillTable()
	return self.db.factionrealm.skills;
end

function MrTrader:RemoveCharacter(name)
	self.db.factionrealm.skills[name] = nil;
end